@@ -8,6 +8,9 @@ MAX_WORKERS = int(os.environ.get('MAX_WORKERS', '16'))
 # Worker pool
 worker_pool = ThreadPoolExecutor(max_workers=MAX_WORKERS)
 
+def tasks(s, jdata, func, output):
+    return [run_analysis(s[i.get("account_id")][i.get("region")],i, func, output) for i in jdata]
+
 def worker(func):
     """
     Runs blocking code asynchronously in worker thread from worker pool
@@ -18,3 +21,7 @@ def worker(func):
         loop = asyncio.get_event_loop()
         return await loop.run_in_executor(worker_pool, pfunc)
     return run
+
+@worker
+def run_analysis(s, record, func, output):
+    if s: output.append(func(s,record))
